Module uim.codec
================
This package contains the Universal Ink Model codec and a decoder for the Wacom Ink Layer Language (WILL) format.

Sub-modules
-----------
* uim.codec.base
* uim.codec.context
* uim.codec.format
* uim.codec.parser
* uim.codec.writer